diff -urN clamav-devel/clamav-milter/clamav-milter.c clamav-devel-log/clamav-milter/clamav-milter.c
--- clamav-devel/clamav-milter/clamav-milter.c	Sun Apr 25 11:30:55 2004
+++ clamav-devel-log/clamav-milter/clamav-milter.c	Tue Apr 27 16:13:04 2004
@@ -808,6 +808,7 @@
 static	int	logClean = 1;	/*
 				 * Add clean items to the log file
 				 */
+static	int	logInfected = 1; /* Redundantly log verbose infected messages */
 static	char	*signature = "-- \nScanned by ClamAv - http://www.clamav.net\n";
 static	time_t	signatureStamp;
 static	char	*templatefile;	/* e-mail to be sent when virus detected */
@@ -853,6 +854,7 @@
 	puts("\t--config-file=FILE\t-c FILE\tRead configuration from FILE.");
 	puts("\t--debug\t\t\t-D\tPrint debug messages.");
 	puts("\t--dont-log-clean\t-C\tDon't add an entry to syslog that a mail is clean.");
+	puts("\t--dont-log-infected\t-I\tDon't add our own entry to syslog that a mail is infected.");
 	puts("\t--dont-scan-on-error\t-d\tPass e-mails through unscanned if a system error occurs.");
 	puts("\t--from=EMAIL\t\t-a EMAIL\tError messages come from here.");
 	puts("\t--force-scan\t\t-f\tForce scan all messages (overrides (-o and -l).");
@@ -920,9 +922,9 @@
 	for(;;) {
 		int opt_index = 0;
 #ifdef	CL_DEBUG
-		const char *args = "bc:CDfF:lm:nNop:PqQ:dhHs:St:U:Vx:";
+		const char *args = "bc:CDfF:Ilm:nNop:PqQ:dhHs:St:U:Vx:";
 #else
-		const char *args = "bc:CDfF:lm:nNop:PqQ:dhHs:St:U:V";
+		const char *args = "bc:CDfF:Ilm:nNop:PqQ:dhHs:St:U:V";
 #endif
 
 		static struct option long_options[] = {
@@ -939,6 +941,9 @@
 				"dont-log-clean", 0, NULL, 'C'
 			},
 			{
+				"dont-log-infected", 0, NULL, 'I'
+			},
+			{
 				"dont-scan-on-error", 0, NULL, 'd'
 			},
 			{
@@ -1049,6 +1054,9 @@
 			case 'i':	/* pidfile */
 				pidfile = optarg;
 				break;
+			case 'I':	/* pidfile */
+				logInfected = 0;
+				break;
 			case 'l':	/* scan mail from the lan */
 				lflag++;
 				break;
@@ -2220,7 +2228,11 @@
 		if(!nflag)
 			smfi_addheader(ctx, "X-Virus-Status", "Infected");
 
-		if(use_syslog) {
+#ifndef CL_DEBUG
+		if(use_syslog && logInfected) {
+#else
+		{
+#endif
 			/*
 			 * Setup err as a list of recipients
 			 */
@@ -2257,8 +2269,9 @@
 			}
 			(void)strcpy(ptr, "\n");
 
-			/* Include the sendmail queue ID in the log */
-			syslog(LOG_NOTICE, "%s: %s%s", sendmailId, mess, err);
+				/* Include the sendmail queue ID in the log */
+			if(use_syslog)
+				syslog(LOG_NOTICE, "%s: %s%s", sendmailId, mess, err);
 #ifdef	CL_DEBUG
 			cli_dbgmsg("%s\n", err);
 #endif
diff -urN clamav-devel/docs/man/clamav-milter.8 clamav-devel-log/docs/man/clamav-milter.8
--- clamav-devel/docs/man/clamav-milter.8	Sun Apr 25 11:30:56 2004
+++ clamav-devel-log/docs/man/clamav-milter.8	Tue Apr 27 16:13:04 2004
@@ -64,6 +64,13 @@
 \fBclamav.conf\fR since it gives a feel-good factor.
 This option turns that off.
 .TP
+\fB-I, \-\-dont-log-infected\fR
+Messages with viruses are usually logged if SysLog is set in
+\fBclamav.conf\fR since it gives a feel-good factor.
+
+However, since sendmail will log it for us (if MilterLogLevel > 1 or if LOG_LEVEL is high enough), you may find that to be redundant.
+This option turns that off.
+.TP
 \fB-d, \-\-dont-scan-on-error\fR
 If a system error occurs pass messages through unscanned,
 usually when a system error occurs the milter raises a temporary failure which
